//
//  MainMenu.swift
//  ArkitDoushiQi
//
//  Created by Johan LACHENAL on 16/05/2024.
//

import SwiftUI

struct MainMenu: View {
    @EnvironmentObject var languageSettings: LanguageSettings
    let playButtonText: LocalizedStringKey
    let registeredGamesButtonText: LocalizedStringKey
    @State private var action: Int? = 0
    @AppStorage("isDarkMode") private var isDarkMode = false
    @State private var reloadView = false
    @State private var showLanguagePicker = false
    @ScaledMetric(relativeTo: .body) var scaledPadding: CGFloat = 10
    @Environment(\.colorScheme) var colorScheme

    var body: some View {
        NavigationStack {
            ZStack {
                VStack {
                    Spacer().frame(height: 50)
                    
                    Text("DOUSHIQI")
                        .font(.custom("Nuku Nuku", size: 48, relativeTo: .largeTitle))
                        .padding()
                        .foregroundColor(colorScheme == .dark ? .white : .black)
                    
                    Text("GAME")
                        .font(.custom("Nuku Nuku", size: 48, relativeTo: .largeTitle))
                        .foregroundColor(colorScheme == .dark ? .white : .black)
                    
                    Spacer()

                    NavigationLink(destination: GameParametersMenuView()) {
                        Text(playButtonText)
                            .font(.custom("Nuku Nuku", size: 32, relativeTo: .title))
                            .bold()
                            .frame(maxWidth: .infinity)
                            .padding()
                            .background(Color.white.opacity(0.2))
                            .foregroundColor(colorScheme == .dark ? .white : .black)
                            .cornerRadius(10)
                            .overlay(
                                RoundedRectangle(cornerRadius: 10)
                                    .stroke(colorScheme == .dark ? Color.white : Color.black, lineWidth: 2)
                            )
                            .shadow(radius: 10)
                            .padding(scaledPadding)
                    }
                    .padding(.horizontal, 50)

                    Spacer().frame(height: 40)

                    NavigationLink(destination: PartyListView()) {
                        Text(registeredGamesButtonText)
                            .font(.custom("Nuku Nuku", size: 18, relativeTo: .body))
                            .padding()
                            .background(Color.gray.opacity(0.7))
                            .foregroundColor(colorScheme == .dark ? .white : .black)
                            .cornerRadius(10)
                            .shadow(radius: 5)
                            .padding(scaledPadding)
                    }
                    .padding(.horizontal, 50)

                    Spacer().frame(height: 20)
                    
                    HStack {
                        Button(action: {
                            isDarkMode.toggle()
                        }) {
                            Image(systemName: isDarkMode ? "sun.max.fill" : "moon.fill")
                                .foregroundColor(colorScheme == .dark ? .white : .black)
                                .padding()
                                .scaleEffect(1.2)
                        }

                        Button(action: {
                            showLanguagePicker.toggle()
                        }) {
                            Image(systemName: "globe")
                                .foregroundColor(colorScheme == .dark ? .white : .black)
                                .padding()
                                .scaleEffect(1.2)
                        }
                        .sheet(isPresented: $showLanguagePicker) {
                            LanguagePickerView(showLanguagePicker: $showLanguagePicker)
                                .environmentObject(languageSettings)
                        }
                    }
                    .padding(scaledPadding)
                    
                    Spacer()
                }
                .padding(EdgeInsets(top: 10, leading: 32, bottom: 10, trailing: 32))
            }
            .environmentObject(languageSettings)
            .onReceive(NotificationCenter.default.publisher(for: NSNotification.Name("LanguageChanged"))) { _ in
                self.reloadView.toggle()
            }
        }
    }
}

struct MainMenu_Previews: PreviewProvider {
    static var previews: some View {
        MainMenu(playButtonText: "Play", registeredGamesButtonText: "Registered Games")
            .environmentObject(LanguageSettings(selectedLanguage: .French))
    }
}
